<?php
/**
 * Created by PhpStorm.
 * User: b2wsra
 * Date: 09.10.2018
 * Time: 17:03
 */

namespace Codevision\Language;

class ACFPolyLang {

	/**
	 * @var string
	 */
	private $text_domain;
	/**
	 * @var array
	 */
	private $slugs;

	/**
	 * @var array
	 */
	private $data;

	/**
	 * @var \StringTemplate\Engine
	 */
	private $engine;

	/**
	 * CodevisionAcfPolyLang constructor.
	 *
	 * @param string $text_domain
	 * @param array $slugs
	 * @param array $data
	 */
	public function __construct( string $text_domain, array $slugs, array $data ) {
		$this->text_domain = $text_domain;
		$this->slugs       = $slugs;
		$this->data        = $data;

		$this->engine = new \StringTemplate\Engine();

	}


	public function init() {

		add_action('current_screen', [ $this, 'init_screen' ] );

	}

	function init_screen( $screen ) {

		if ( ! is_admin() ) {
			return;
		}

		$enable_filter = array_filter( $this->slugs, function( $slug ) use ( $screen ) {
			return strpos( $screen->id, $slug ) !== false;
		} );

		if ( ! $enable_filter ) {
			return;
		}

		add_filter( 'acf/load_field', [ $this, 'load_field' ] );
		add_filter( 'acf/prepare_field', [ $this, 'load_field' ] );
	}

	private function trans( $label ) {
		return $this->engine->render( __( $label, $this->text_domain ), $this->data );
	}

	function load_field( $field ) {

		$text_fields = [
			'label',
			'instructions',
			'message'
		];

		foreach ( $text_fields as $label ) {

			if ( ! array_key_exists( $label, $field ) ) {
				continue;
			}

			$field[ $label ] = $this->trans( $field[ $label ] );
		}


		if ( array_key_exists( 'ui_on_text', $field ) ) {
			$field['ui_on_text'] = __( 'Yes', $this->text_domain );
		}

		if ( array_key_exists( 'ui_off_text', $field ) ) {
			$field['ui_off_text'] = __( 'No', $this->text_domain );
		}

		if ( array_key_exists( 'choices', $field ) ) {

			$choices = $field['choices'];

			foreach ( $choices as $key => & $desc ) {
				$desc = $this->trans( $desc );
			}

			$field['choices'] = $choices;
		}


		return $field;
	}
}