<?php
/**
 * Created by PhpStorm.
 * User: burstfire
 * Date: 27.08.18
 * Time: 13:30
 */

namespace Codevision\View;

use Codevision\Util\Helper;
use \Twig\TwigFunction;
use \Twig\Environment;
use \Twig\Loader\FilesystemLoader;

class TwigRenderer {

    /**
     * @var \Twig_Environment
     */
    private $twig;

    /**
     * @var string
     */
    private $plugin_slug;

    /**
     * @var bool
     */
    private $cache;

    /**
     * @var string|bool
     */
    private $template_path;

    public function __construct( $plugin_slug, $cache = false, $template_path = false ) {
        $this->plugin_slug = $plugin_slug;
        $this->cache = $cache;
        $this->template_path = $template_path;
    }

    private function load_twig() {

        if ( $this->twig ) {
            return;
        }

        if ( ! $this->template_path ) {
            $this->template_path = __DIR__ . '/../../templates';
        }

        $loader = new FilesystemLoader( $this->template_path );

        $this->twig = new Environment( $loader, array(
            'cache' => $this->cache,
        ) );

        $this->twig->addFunction( new TwigFunction( 'wp_trans', function ( $trans ) {
            return __( $trans, $this->plugin_slug );
        }, array( 'is_safe' => array( 'html' ) ) ) );

    }

    public function view( $template, $data = array(), $extension = '.twig' ) {

        $this->load_twig();

        if ( ! $template ) {
            Helper::log( sprintf( '[ Template Renderer ] A template is required to view data' ), 'error' );

            return '';
        }

        return $this->twig->render( $template . $extension, $data );
    }
}
